History
##################

0.2.0 (2023-12-24)
=====================

- Add cache punting.
- Make C docstrings type parsable (good for Sphinx) and add a script that can create a mypy stub file.
- Development Status :: 4 - Beta

0.1.2 (2023-10-03)
=====================

- First release. Development Status :: 3 - Alpha
